@@ -15,14 +15,14 @@ from __future__ import annotations
 import datetime
 import mimetypes
 import shutil
-from collections.abc import KeysView, MutableMapping
+from collections.abc import ItemsView, Iterator, KeysView, MutableMapping, ValuesView
 from contextlib import ExitStack, suppress
 from decimal import Decimal
 from io import BytesIO, RawIOBase
 from pathlib import Path
 from subprocess import run
 from tempfile import NamedTemporaryFile
-from typing import BinaryIO, Callable, ItemsView, Iterator, TypeVar, ValuesView
+from typing import BinaryIO, Callable, TypeVar
 from warnings import warn
 
 from pikepdf._augments import augment_override_cpp, augments
@@ -163,9 +163,7 @@ class Extend_Pdf:
         bio.seek(0)
         return bio
 
-    def _repr_mimebundle_(
-        self, include=None, exclude=None
-    ):  # pylint: disable=unused-argument
+    def _repr_mimebundle_(self, include=None, exclude=None):  # pylint: disable=unused-argument
         pdf_data = self._quick_save().read()
         data = {
             'application/pdf': pdf_data,
@@ -396,19 +394,24 @@ class Extend_Pdf:
             description = str(filename_or_stream)
             closing_stream = True
 
-        check_stream_is_usable(stream)
-        pdf = Pdf._open(
-            stream,
-            password=password,
-            hex_password=hex_password,
-            ignore_xref_streams=ignore_xref_streams,
-            suppress_warnings=suppress_warnings,
-            attempt_recovery=attempt_recovery,
-            inherit_page_attributes=inherit_page_attributes,
-            access_mode=access_mode,
-            description=description,
-            closing_stream=closing_stream,
-        )
+        try:
+            check_stream_is_usable(stream)
+            pdf = Pdf._open(
+                stream,
+                password=password,
+                hex_password=hex_password,
+                ignore_xref_streams=ignore_xref_streams,
+                suppress_warnings=suppress_warnings,
+                attempt_recovery=attempt_recovery,
+                inherit_page_attributes=inherit_page_attributes,
+                access_mode=access_mode,
+                description=description,
+                closing_stream=closing_stream,
+            )
+        except Exception:
+            if stream is not None and closing_stream:
+                stream.close()
+            raise
         pdf._tmp_stream = stream if allow_overwriting_input else None
         pdf._original_filename = original_filename
         return pdf
